externals_tracing_module_context

Function externals_tracing_module_context 

pub fn externals_tracing_module_context(
    compile_time_info: Vc<CompileTimeInfo>,
    resolve_typescript: bool,
    prune: Option<(FileSystemPath, ResolvedVc<Glob>)>,
) -> Vc<ModuleAssetContext>
prune skips matching files as the graph is walked, rather than filtering them out of the result afterwards.